from typing import List

__all__: List[str]

def histogram_bin_edges(a, bins=..., range=..., weights=...): ...
def histogram(a, bins=..., range=..., normed=..., weights=..., density=...): ...
def histogramdd(sample, bins=..., range=..., normed=..., weights=..., density=...): ...
